{  TDEventRecorder class is designed to store method pointers for Event handlers
   in Delphi

  Copyright  1998. Galina Tydykov (Boston, USA, CompuServe 104052,2577).
  Published by permission of SonaMed Corp}

unit EvRecorder;

interface

uses
  Classes, Controls, forms;

(************************************************************************)

 type

  TDEventRecorder = class;

  TEventItem = class
  private
     fOwner:TDEventRecorder;
  protected
  public
     property Owner:TDEventRecorder read fOwner;
     Constructor Create(owner:TDEventRecorder); virtual;
  end ;

  TMultiEventItem = class(TEventItem)
  public
     OnTimer: TNotifyEvent;
     OnClick: TNotifyEvent;
     OnMouseMove: TMouseMoveEvent;
     OnMouseDown: TMouseEvent;
     OnMouseUp: TMouseEvent ;
   end ;


  TClickItem = class(TEventItem)
  public
     OnClick: TNotifyEvent;
   end ;

  TTimerItem = class(TEventItem)
  public
     OnTimer: TNotifyEvent;
   end ;

  TMouseDownItem = class(TEventItem)
  public
     OnMouseDown: TMouseEvent;
   end ;

  TDEventRecorder = class(TObject)
  private
    { Private declarations }
    fList: TList;
    function GetCount: integer;
    function GetEventItem(Index: Integer): TEventItem;
    procedure PutEventItem(Index: Integer; Item: TEventItem);
   protected
   public
    { Public declarations }
     property EventItem[Index: Integer]: TEventItem read GetEventItem write PutEventItem;
     property Count: Integer read GetCount;
     procedure delete(Index: Integer);
     Constructor Create;
     destructor Destroy; override;
     procedure Clear;
   end;


implementation


{  TEventItem }
 Constructor TEventItem.Create(owner:TDEventRecorder);
 begin
   fowner:=owner;
   fowner.flist.add(self);
 end;


{TDEventRecorder}

Constructor TDEventRecorder.Create;
begin
  fList:=TList.create;
end;

destructor TDEventRecorder.Destroy;
begin
  Clear;
  fList.free;
  inherited Destroy;
end;

function TDEventRecorder.GetCount: integer;
begin
  result:=fList.Count;
end;


procedure TDEventRecorder.Clear;
var
 i: integer;
begin
  for i:=0 to fList.count-1 do
    delete(fList.count-1);
end;


function TDEventRecorder.GetEventItem(Index: Integer): TEventItem;
begin
  if (Index < 0) or (Index >= fList.Count) then
      raise EListError.Create('EventList Error');
  Result :=TEventItem(fList.items[Index]);
end;


procedure TDEventRecorder.PutEventItem(Index: Integer; Item: TEventItem);
begin
  if (Index < 0) or (Index >= fList.Count) then
      raise EListError.Create('EventList Error');
  TEventItem((fList.items[Index])^):= Item;
end;

procedure TDEventRecorder.delete(Index: Integer);
begin
  EventItem[Index].free;
  flist.Delete(Index);
end;

{ This software is provided "AS IS," without a warranty of any kind.
 *ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES,
 *INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A
 *PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED.
 *SONAMED SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THE SOFTWARE OR
 *ITS DERIVATIVES. IN NO EVENT WILL SONAMED BE LIABLE FOR ANY LOST
 *REVENUE, PROFIT OR DATA, OR FOR DIRECT,INDIRECT, SPECIAL, CONSEQUENTIAL,
 *INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE
 *THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE
 *SOFTWARE, EVEN IF SONAMED HAS BEEN ADVISED OF THE POSSIBILITY OF
 *SUCH DAMAGES
}

end.
